@@ -86,7 +86,7 @@
 #define KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KNOTIFICATIONS_NO_DEPRECATED
-#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
+#  define KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KNOTIFICATIONS_NO_DEPRECATED_WARNINGS
 #  define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE KNOTIFICATIONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55100
+#    define KNOTIFICATIONS_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -136,5 +136,12 @@
 #define KNOTIFICATIONS_DEPRECATED_VERSION_5(minor, text)      KNOTIFICATIONS_DEPRECATED_VERSION_5_##minor(text)
 #define KNOTIFICATIONS_DEPRECATED_VERSION(major, minor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNOTIFICATIONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KNOTIFICATIONS_DEPRECATED_VERSION(major, minor, text)
+#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNOTIFICATIONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KNOTIFICATIONS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KNOTIFICATIONS_EXPORT_H */
